---

kanban-plugin: basic

---

## To do

- [ ] # Library Design<br>- [ ] Component diagram<br>- [ ] Class diagram


## In progess



## Done

**Completato**
- [x] # Initial documentation<br><br>- [x] requirements specification<br>- [x] project plan<br>- [x] use case diagram<br>- [x] development process state machine
- [x] # Set up continuous integration<br><br>- [x] `Pylint`:<br>	- [x] install `pylint` on GitHub<br>	- [x] install `pylint` locally<br>	- [x] make a script to reject low-score code<br>- [x] Tests:<br>	- [x] define test cases<br>	- [x] implement test cases<br>	- [x] make a script to reject failing commits
- [ ] # Initial chores<br>- [x] open repo<br>- [x] first commit<br>- [x] set project structure




%% kanban:settings
```
{"kanban-plugin":"basic"}
```
%%